@@ -1,5 +1,5 @@
 # -*- Mode: cperl; cperl-indent-level: 4 -*-
-# $Id: Harness.pm,v 1.69 2003/11/14 15:25:31 andy Exp $
+# $Id: Harness.pm,v 1.76 2003/11/25 04:41:03 andy Exp $
 
 package Test::Harness;
 
@@ -11,10 +11,17 @@ use Benchmark;
 use Config;
 use strict;
 
-use vars qw($VERSION $Verbose $Switches $Have_Devel_Corestack $Curtest
-            $Columns $verbose $switches $ML $Strap
-            @ISA @EXPORT @EXPORT_OK $Last_ML_Print
-           );
+use vars qw(
+    $VERSION 
+    @ISA @EXPORT @EXPORT_OK 
+    $Verbose $Switches $Debug
+    $verbose $switches $debug
+    $Have_Devel_Corestack
+    $Curtest
+    $Columns 
+    $ML $Last_ML_Print
+    $Strap
+);
 
 =head1 NAME
 
@@ -22,17 +29,18 @@ Test::Harness - Run Perl standard test scripts with statistics
 
 =head1 VERSION
 
-Version 2.36
+Version 2.38
 
-    $Header: /home/cvs/test-harness/lib/Test/Harness.pm,v 1.69 2003/11/14 15:25:31 andy Exp $
+    $Header: /home/cvs/test-harness/lib/Test/Harness.pm,v 1.76 2003/11/25 04:41:03 andy Exp $
 
 =cut
 
-$VERSION = '2.36';
+$VERSION = '2.38';
 
 # Backwards compatibility for exportable variable names.
 *verbose  = *Verbose;
 *switches = *Switches;
+*debug    = *Debug;
 
 $Have_Devel_Corestack = 0;
 
@@ -57,6 +65,7 @@ $Strap = Test::Harness::Straps->new;
 @EXPORT_OK = qw($verbose $switches);
 
 $Verbose  = $ENV{HARNESS_VERBOSE} || 0;
+$Debug    = $ENV{HARNESS_DEBUG} || 0;
 $Switches = "-w";
 $Columns  = $ENV{HARNESS_COLUMNS} || $ENV{COLUMNS} || 80;
 $Columns--;             # Some shells have trouble with a full line of text.
@@ -245,9 +254,9 @@ Test::Harness.  They are exported on request.
 
 =over 4
 
-=item B<$Test::Harness::verbose>
+=item B<$Test::Harness::Verbose>
 
-The global variable C<$Test::Harness::verbose> is exportable and can be
+The global variable C<$Test::Harness::Verbose> is exportable and can be
 used to let C<runtests()> display the standard output of the script
 without altering the behavior otherwise.  The F<prove> utility's C<-v>
 flag will set this.
@@ -459,16 +468,21 @@ sub _run_all_tests {
 
     my $width = _leader_width(@tests);
     foreach my $tfile (@tests) {
+	if ( $Test::Harness::Debug ) {
+	    print "# Running: ", $Strap->_command_line($tfile), "\n";
+	}
+
         $Last_ML_Print = 0;  # so each test prints at least once
         my($leader, $ml) = _mk_leader($tfile, $width);
         local $ML = $ml;
+
         print $leader;
 
         $tot{files}++;
 
         $Strap->{_seen_header} = 0;
         my %results = $Strap->analyze_file($tfile) or
-          do { warn "$Strap->{error}\n";  next };
+          do { warn $Strap->{error}, "\n";  next };
 
         # state of the current test.
         my @failed = grep { !$results{details}[$_-1]{ok} }
@@ -974,7 +988,7 @@ __END__
 
 C<&runtests> is exported by Test::Harness by default.
 
-C<$verbose> and C<$switches> are exported upon request.
+C<$verbose>, C<$switches> and C<$debug> are exported upon request.
 
 =head1 DIAGNOSTICS
 
@@ -1034,6 +1048,13 @@ C<perlcc> before running it.
 B<NOTE> This currently only works when sitting in the perl source
 directory!
 
+=item C<HARNESS_DEBUG>
+
+If true, Test::Harness will print debugging information about itself as
+it runs the tests.  This is different from C<HARNESS_VERBOSE>, which prints
+the output from the test being run.  Setting C<$Test::Harness::Debug> will
+override this, or you can use the C<-d> switch in the F<prove> utility.
+
 =item C<HARNESS_FILELEAK_IN_DIR>
 
 When set to the name of a directory, harness will check after each
@@ -1080,7 +1101,8 @@ run all tests with all warnings enabled.
 =item C<HARNESS_VERBOSE>
 
 If true, Test::Harness will output the verbose results of running
-its tests.  Setting C<$Test::Harness::verbose> will override this.
+its tests.  Setting C<$Test::Harness::verbose> will override this,
+or you can use the C<-v> switch in the F<prove> utility.
 
 =back
 
